@@ -1,9 +1,11 @@
+import datetime
+import time
 from twisted.trial import unittest
 from twisted.internet import defer
 from zope.interface import implements
 
 from txtorcon import Circuit, Stream, TorControlProtocol, TorState
-from txtorcon.interface import IRouterContainer, ICircuitListener, ICircuitContainer, CircuitListenerMixin, ITorControlProtocol
+from txtorcon.interface import IRouterContainer, ICircuitListener, ICircuitContainer, CircuitListenerMixin
 
 
 class FakeTorController(object):
@@ -42,9 +44,9 @@ class FakeTorController(object):
     def find_circuit(self, circid):
         return self.circuits[circid]
 
-    def close_circuit(self, circ):
-        del self.circuits[circ.id]
-        return defer.succeed('OK')
+    def close_circuit(self, circid):
+        del self.circuits[circid]
+        return defer.succeed('')
 
 
 class FakeLocation:
@@ -71,6 +73,33 @@ examples = ['CIRC 365 LAUNCHED PURPOSE=GENERAL',
 
 class CircuitTests(unittest.TestCase):
 
+    def test_age(self):
+        """
+        make sure age does something sensible at least once.
+        """
+        tor = FakeTorController()
+
+        circuit = Circuit(tor)
+        now = datetime.datetime.now()
+        update = '1 LAUNCHED PURPOSE=GENERAL TIME_CREATED=%s' % time.strftime('%Y-%m-%dT%H:%M:%S')
+        circuit.update(update.split())
+        diff = circuit.age(now=now)
+        self.assertEquals(diff, 0)
+        self.assertTrue(circuit.time_created is not None)
+
+    def test_no_age_yet(self):
+        """
+        make sure age doesn't explode if there's no TIME_CREATED flag.
+        """
+        tor = FakeTorController()
+
+        circuit = Circuit(tor)
+        now = datetime.datetime.now()
+        circuit.update('1 LAUNCHED PURPOSE=GENERAL'.split())
+        self.assertTrue(circuit.time_created is None)
+        diff = circuit.age(now=now)
+        self.assertEquals(diff, None)
+
     def test_listener_mixin(self):
         listener = CircuitListenerMixin()
         from zope.interface.verify import verifyObject
