@@ -33,7 +33,6 @@ class Circuit(object):
     :ivar state:
         contains a string from Tor describing the current state of the
         stream. From control-spec.txt section 4.1.2, these are:
-
             - NEW: New request to connect
             - NEWRESOLVE: New request to resolve an address
             - REMAP: Address re-mapped to another
@@ -47,7 +46,6 @@ class Circuit(object):
     :ivar purpose:
         The reason this circuit was built. Values can currently be one
         of (but see control-spec.txt 4.1.1):
-
           - GENERAL
           - HS_CLIENT_INTRO
           - HS_CLIENT_REND
@@ -58,6 +56,7 @@ class Circuit(object):
 
         For most purposes, you'll want to look at GENERAL circuits only.
 
+
     :ivar id:
         The ID of this circuit, a number (or None if unset).
     """
@@ -139,7 +138,10 @@ class Circuit(object):
         return (now - self.time_created).seconds
 
     def _create_flags(self, kw):
-        "this clones the kw dict, adding a lower-case version of every key (duplicated in stream.py; put in util?)"
+        """
+        this clones the kw dict, adding a lower-case version of every
+        key (duplicated in stream.py; put in util?)
+        """
 
         flags = {}
         for k in kw.keys():
@@ -169,8 +171,9 @@ class Circuit(object):
             self.path = []
             [x.circuit_launched(self) for x in self.listeners]
         else:
-            if self.state != 'FAILED' and self.state != 'CLOSED' and len(args) > 2:
-                self.update_path(args[2].split(','))
+            if self.state != 'FAILED' and self.state != 'CLOSED':
+                if len(args) > 2:
+                    self.update_path(args[2].split(','))
 
         if self.state == 'BUILT':
             [x.circuit_built(self) for x in self.listeners]
@@ -235,4 +238,6 @@ class Circuit(object):
                 oldpath = self.path
 
     def __str__(self):
-        return "<Circuit %d %s [%s] for %s>" % (self.id, self.state, ' '.join(map(lambda x: x.ip, self.path)), self.purpose)
+        path = ' '.join(map(lambda x: x.ip, self.path))
+        return "<Circuit %d %s [%s] for %s>" % (self.id, self.state, path,
+                                                self.purpose)
