@@ -97,6 +97,9 @@ class Stream(object):
         """If available, the port from which this Stream
         originated. See get_process() also."""
 
+        self.flags = {}
+        """All flags from last update to this Stream. str->str"""
+
         self._closing_deferred = None
         """Internal. Holds Deferred that will callback when this
         stream is CLOSED, FAILED (or DETACHED??)"""
@@ -161,6 +164,7 @@ class Stream(object):
                 raise RuntimeError("Update for wrong stream.")
 
         kw = find_keywords(args)
+        self.flags = kw
 
         if 'SOURCE_ADDR' in kw:
             last_colon = kw['SOURCE_ADDR'].rfind(':')
@@ -170,7 +174,7 @@ class Stream(object):
             self.source_port = int(kw['SOURCE_ADDR'][last_colon + 1:])
 
         self.state = args[1]
-        if self.state in ['NEW', 'SUCCEEDED']:
+        if self.state in ['NEW', 'NEWRESOLVE', 'SUCCEEDED']:
             if self.target_host is None:
                 last_colon = args[3].rfind(':')
                 self.target_host = args[3][:last_colon]
@@ -217,11 +221,8 @@ class Stream(object):
             flags = self._create_flags(kw)
             [x.stream_detach(self, **flags) for x in self.listeners]
 
-        elif self.state == 'NEWRESOLVE':
-            pass  # print 'NEWRESOLVE',self,args
-
-        elif self.state == 'SENTRESOLVE':
-            pass  # print 'SENTRESOLVE',self,args
+        elif self.state in ['NEWRESOLVE', 'SENTRESOLVE']:
+            pass  # print self.state, self, args
 
         else:
             raise RuntimeError("Unknown state: %s" % self.state)
