@@ -33,11 +33,8 @@ def create_geoip(fname):
     if GeoIP is None:
         return None
 
-    try:
-        return GeoIP.open(fname, GeoIP.GEOIP_STANDARD)
-
-    except GeoIP.error:
-        raise IOError("Can't load %s" % fname)
+    ## just letting any errors make it out
+    return GeoIP.open(fname, GeoIP.GEOIP_STANDARD)
 
 
 def maybe_create_db(path):
@@ -83,7 +80,7 @@ def find_tor_binary(globs=('/usr/sbin/', '/usr/bin/',
     # Try to find the tor executable using the shell
     if system_tor:
         try:
-            proc = subprocess.Popen(('type -p tor', ), executable='/bin/bash',
+            proc = subprocess.Popen(('which tor'),
                                     stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                                     shell=True)
         except OSError:
@@ -179,8 +176,6 @@ def process_from_address(addr, port, torstate=None):
     if len(lines) > 1:
         return int(lines[1].split()[1])
 
-    return None
-
 
 def hmac_sha256(key, msg):
     """
